=====
Cache
=====

.. automodule:: werkzeug.contrib.cache


Cache System API
================

.. autoclass:: BaseCache
   :members:


Cache Systems
=============

.. autoclass:: NullCache

.. autoclass:: SimpleCache

.. autoclass:: MemcachedCache

.. autoclass:: GAEMemcachedCache

.. autoclass:: FileSystemCache
